@@ -1,6 +1,6 @@
 from ._src.imath import PiMultiple
 from ._src.imath import acos, acosh, asin, asinh, atan, atan2, atanh
-from ._src.imath import cos, cosh, degrees, digamma, dist, e, erf, erfc
-from ._src.imath import exp, expm1, gamma, fsum, hypot, inf, lgamma
+from ._src.imath import cos, cosh, degrees, digamma, dist, dot, e, erf
+from ._src.imath import erfc, exp, expm1, gamma, fsum, hypot, inf, lgamma
 from ._src.imath import log, log10, log1p, log2, pi, pow, radians, sin
 from ._src.imath import sinh, sqrt, tan, tanh, tau
